@@ -12,19 +12,24 @@
 #include <gstreamermm/enums.h>
 #include <gstreamermm/error.h>
 #include <gstreamermm/event.h>
+#include <gstreamermm/filter.h>
 #include <gstreamermm/format.h>
 #include <gstreamermm/index.h>
+#include <gstreamermm/indexfactory.h>
 #include <gstreamermm/iterator.h>
 #include <gstreamermm/message.h>
 #include <gstreamermm/object.h>
 #include <gstreamermm/pad.h>
 #include <gstreamermm/padtemplate.h>
+#include <gstreamermm/parse.h>
 #include <gstreamermm/pipeline.h>
 #include <gstreamermm/plugin.h>
 #include <gstreamermm/pluginfeature.h>
 #include <gstreamermm/query.h>
 #include <gstreamermm/structure.h>
 #include <gstreamermm/systemclock.h>
+#include <gstreamermm/task.h>
+#include <gstreamermm/urihandler.h>
 #include <gstreamermm/value.h>
 #include <gstreamermm/xml.h>
 
